Crate const_gen[−][src]
Macros
Like const_declaration, but for const array types
A macro to help in the creation of const declarations. Allows this syntax:
const_declaration!(visibility VAR_NAME = value)
This is syntactic sugar for calling the CompileConst::const_declaration
function.
A macro to help in the creation of const definitions. Allows this syntax:
const_definition!(#[attribute1] #[attributeN] visibility TypeName)
This is syntactic sugar for calling the CompileConst::const_definition
function.
Traits
Trait which defines how a type should be represented as a constant
Trait which defines how an array-representable type should be represented as a const array
Derive Macros
Derives the CompileConst trait for structs and enums. Requires that all fields also implement the CompileConst trait.